@@ -3,7 +3,7 @@ library(testit)
 test_site = function(theme) {
   dir.create(d1 <- tempfile())
   on.exit(unlink(d1, recursive = TRUE), add = TRUE)
-  d2 = new_site(d1, theme = theme)
+  d2 = new_site(d1, theme = theme, serve = FALSE)
   xfun::in_dir(d2, blogdown::build_site(build_rmd = 'newfile'))
   xfun::normalize_path(d1) %==% xfun::normalize_path(d2)
 }
